package edu.sc.seis.cormorant.network;

import java.util.ArrayList;
import java.util.Iterator;
import org.apache.log4j.Category;
import edu.iris.Fissures.IfNetwork.ConcreteNetworkAccessPOA;
import edu.iris.Fissures.IfNetwork.NetworkAccess;
import edu.iris.Fissures.IfNetwork.NetworkFinderPOA;
import edu.iris.Fissures.IfNetwork.NetworkId;
import edu.iris.Fissures.IfNetwork.NetworkNotFound;
import edu.iris.Fissures.network.NetworkIdUtil;

/**
 * NetworkFinderImpl.java
 *
 *
 * Created: Thu Mar 15 12:21:24 2001
 *
 * @author Philip Crotwell
 * @version
 */

public class NetworkFinderImpl extends NetworkFinderPOA {
    
    public NetworkFinderImpl(NetworkServantLocator locator) {
        this.locator = locator;
    }

    //
    // IDL:iris.edu/Fissures/IfNetwork/NetworkFinder/retrieve_by_id:1.0
    //
    /**
     * Only returns reals. Virtuals do not have a code
     **/

    public NetworkAccess retrieve_by_id(NetworkId id)
        throws NetworkNotFound {
	logger.debug("retreive_by_id: "+NetworkIdUtil.toString(id));
        return locator.getNetworkAccess(id);
    }

    //
    // IDL:iris.edu/Fissures/IfNetwork/NetworkFinder/retrieve_by_code:1.0
    //
    /**
     * Only returns reals. Virtuals do not have a code
     **/

    public NetworkAccess[] retrieve_by_code(String code)
        throws NetworkNotFound {
        Iterator it = locator.getNetworkIterator();
        ArrayList array = new ArrayList();
        String key;
        while (it.hasNext()) {
	    Object keyObj = it.next();
	    logger.debug("retrieve_by_code "+keyObj.getClass().getName());	    
            key = (String)keyObj;
            if (locator.objKeyToNetworkCode(key).equals(code)) {
                array.add(key);
            }
        }
        NetworkAccess[] access = new NetworkAccess[array.size()];
        for (int i=0; i<access.length; i++) {
            access[i] = locator.getNetworkAccess((String)array.get(i));
        }
        return access;
    }

    //
    // IDL:iris.edu/Fissures/IfNetwork/NetworkFinder/retrieve_by_name:1.0
    //
    /***/

    public NetworkAccess[] retrieve_by_name(String name)
        throws NetworkNotFound {
        Iterator it = locator.getNetworkIterator();
        ArrayList array = new ArrayList();
        String key;
        ConcreteNetworkAccessPOA netPOA;
        while (it.hasNext()) {
            key = (String)it.next();
            netPOA = locator.getNetworkAccessPOA(key);
            if (netPOA.get_attributes().getName().equals(name)) {
                array.add(key);
            }
        }
        NetworkAccess[] access = new NetworkAccess[array.size()];
        for (int i=0; i<access.length; i++) {
            access[i] = locator.getNetworkAccess((NetworkId)array.get(i));
        }
        return access;
    }

    //
    // IDL:iris.edu/Fissures/IfNetwork/NetworkFinder/retrieve_all:1.0
    //
    /***/

    public NetworkAccess[] retrieve_all() {
	try {
	    Iterator it = locator.getNetworkIterator();
	    ArrayList array = new ArrayList();
	    String key;
	    while (it.hasNext()) {
		key = (String)it.next();
		array.add(key);
	    }
	    NetworkAccess[] access = new NetworkAccess[array.size()];
	    for (int i=0; i<access.length; i++) {
		access[i] = locator.getNetworkAccess((String)array.get(i));
	    }
	    return access;
	} catch (Exception e) {
	    logger.error("NetworkFinder retrieve_all ", e);
	    throw new org.omg.CORBA.UNKNOWN(e.getMessage());
	} // end of try-catch	
    }

    protected NetworkServantLocator locator;

    static Category logger = Category.getInstance(NetworkFinderImpl.class.getName());

} // NetworkFinderImpl
